#include <iostream>
#include <string>
#include <sstream>
#include <stdlib.h>

// leak
//
// ... by Eli Fulkerson.  See http://www.elifulkerson.com for updates
//

/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using namespace std;

int main(int argc, char* argv[]) {

	string input = "";
	string output = "";

	// by default just the one header line.
	int num_to_ignore = 1;
	bool mode_color = false;
	
	//parse some arguments
	for ( int i = 0; i < argc; i++) {

		std::string arg = argv[i];
		
		if (arg == "-n") {
			if (i + 1 < argc) {
				num_to_ignore = atoi(argv[i+1]);
			}
		}

		if (arg == "-c") {
			mode_color = true;
		}

		if (arg == "-v" || arg == "--version") {
			cout << "leak v0.1  27 October 2015" << endl
				 << "by Eli Fulkerson.  See http://www.elifulkerson.com for updates" << endl << flush;
			return 0;
		}


		if (arg == "-h" || arg == "--help" || arg == "--usage" || arg == "-?" || arg == "/?" || arg == "/h") {

			cout << "Leak reads stdin.  It writes the first (-n X) lines to stderr and" << endl;
			cout << "the remainder to stdout.  For instance... " << endl;
			cout << endl;
			cout << "ps |leak |grep whatever" << endl;
			cout << endl;
			cout << "... will echo the heading line via stderr instead so that grep doesn't eat it." << endl;
			cout << endl;
			
			cout << "Syntax: your_command | leak -n X -c | your_other_commands" << endl
				 << "Options:" << endl
				 << "-n X   : send X lines to stderr (default 1)" << endl
				 << "-c     : colorize the stderr lines" << endl
				 << "-v     : display version information" << endl << flush;
			return 0;
		}
	}

	int lines_so_far = 0;
	while (true) {
		getline(cin, input);

		if (lines_so_far < num_to_ignore) {
			if (mode_color) {
			    cerr << "\033[36m" << input << "\033[39m"<< endl << flush;
			} else {
				cerr << input << endl << flush;
			}
		}
		else {
			cout << input << endl << flush;
		}

		if (!cin) {
			return 0;
		}

		lines_so_far++;
	}

	return 0;
}
